COMPMID-491 Port Utils UNIT tests to new validation

Change-Id: Ia99d26768d780d6d0fee9f5e2ed88f3276ecf3d0
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/89908
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com>
Reviewed-by: Pablo Tello <pablo.tello@arm.com>
diff --git a/utils/TypePrinter.h b/utils/TypePrinter.h
index 041ec18..c955584 100644
--- a/utils/TypePrinter.h
+++ b/utils/TypePrinter.h
@@ -535,7 +535,7 @@
     return os;
 }
 
 //FIXME: Check why this doesn't work and the TensorShape overload is needed
 template <typename T>
 inline std::string to_string(const Dimensions<T> &dimensions)
 {
@@ -552,6 +552,14 @@
     return str.str();
 }
 
+/** Formatted output of the Coordinates type. */
+inline std::string to_string(const Coordinates &coord)
+{
+    std::stringstream str;
+    str << coord;
+    return str.str();
+}
+
 /** Formatted output of the Rectangle type. */
 inline ::std::ostream &operator<<(::std::ostream &os, const Rectangle &rect)
 {
@@ -535,7 +535,7 @@
 }
 
-//FIXME: Check why this doesn't work and the TensorShape overload is needed
+//FIXME: Check why this doesn't work and the TensorShape and Coordinates overload are needed
 template <typename T>
 inline std::string to_string(const Dimensions<T> &dimensions)